| Title: | Autoregressive Integrated Moving Average (ARIMA) Based Disaggregation Methods |
|---|---|
| Description: | We have the code for disaggregation as found in Wei and Stram (1990, <doi:10.1111/j.2517-6161.1990.tb01799.x>), and Hodgess and Wei (1996, "Temporal Disaggregation of Time Series" in Statistical Science I, Nova Publishing). The disaggregation models have different orders of the moving average component. These are based on ARIMA models rather than differencing or using similar time series. |
| Authors: | Erin Hodgess [aut, cre] |
| Maintainer: | Erin Hodgess <[email protected]> |
| License: | GPL-2 | GPL-3 |
| Version: | 0.1.1 |
| Built: | 2026-06-08 07:49:36 UTC |
| Source: | https://github.com/cran/disagmethod |
This uses the Lower Bound method for temporal disaggregation of time series
lower3(x, m = 1)lower3(x, m = 1)
x |
Aggregate Series; must be a ts, xts, or zoo object |
m |
order of disaggregation; 3, 4, 12 |
This function uses the lower bound method found in Hodgess and Wei (1996, "Temporal Disaggregation of Time Series"). We fit an aggregate (p,d,q) model, and produce a disaggregate model of (p,d,0). We generate the disaggregate series based on the disaggregate model.
bigy |
order of the disaggregate model |
fin1 |
final disaggregate series |
Erin Hodgess
Hodgess and Wei (1996, "Temporal Disaggregation of Time Series"), in M. Ahsanullah and D. Bhoj (Eds), "Applied Statistical Science I".
library(tswge) data(tx.unemp.adj) #Monthly seasonally adjusted Texas unemployment data #Create a quarterly sum my.un.q <- aggregate(tx.unemp.adj,nfreq=4) e.low <- lower3(my.un.q,3) sum(e.low$fin1[1:3]) my.un.q[1]library(tswge) data(tx.unemp.adj) #Monthly seasonally adjusted Texas unemployment data #Create a quarterly sum my.un.q <- aggregate(tx.unemp.adj,nfreq=4) e.low <- lower3(my.un.q,3) sum(e.low$fin1[1:3]) my.un.q[1]
This uses the Upper Bound method for temporal disaggregation of time series
upper3(x, m = 1)upper3(x, m = 1)
x |
Aggregate Series; must be a ts, xts, or zoo object |
m |
order of disaggregation; 3, 4, 12 |
This function uses the upper bound method found in Hodgess and Wei (1996, "Temporal Disaggregation of Time Series"). We fit an aggregate (p,d,q) model, and produce a disaggregate model of (p,d,(p+d)). We generate the disaggregate series based on the disaggregate model.
bigy |
order of the disaggregate model |
fin1 |
final disaggregate series |
Erin Hodgess
Hodgess and Wei (1996, "Temporal Disaggregation of Time Series"), in M. Ahsanullah and D. Bhoj (Eds), "Applied Statistical Science I".
library(tswge) data(tx.unemp.adj) #Monthly seasonally adjusted Texas unemployment data #Create a quarterly sum my.un.q <- aggregate(tx.unemp.adj,nfreq=4) e.upp <- upper3(my.un.q,3) sum(e.upp$fin1[1:3]) my.un.q[1]library(tswge) data(tx.unemp.adj) #Monthly seasonally adjusted Texas unemployment data #Create a quarterly sum my.un.q <- aggregate(tx.unemp.adj,nfreq=4) e.upp <- upper3(my.un.q,3) sum(e.upp$fin1[1:3]) my.un.q[1]
This uses the Wei Stram method for temporal disaggregation of time series
weidis3(x, m = 1)weidis3(x, m = 1)
x |
Aggregate Series; must be a ts, xts, or zoo object |
m |
order of disaggregation; 3, 4, 12 |
This function uses the method found in Wei and Stram (1990, <doi:10.1111/j.2517-6161.1990.tb01799.x>). We fit an aggregate (p,d,q) model, and produce a disaggregate model of (p,d,(p+d+1)). We generate the disaggregate series based on the disaggregate model.
bigy |
order of the disaggregate model |
fin1 |
final disaggregate series |
Erin Hodgess
Wei and Stram (1990, <doi:10.1111/j.2517-6161.1990.tb01799.x>)
library(tswge) data(tx.unemp.adj) #Monthly seasonally adjusted Texas unemployment data #Create a quarterly sum my.un.q <- aggregate(tx.unemp.adj,nfreq=4) e.wei <- weidis3(my.un.q,3) sum(e.wei$fin1[1:3]) my.un.q[1]library(tswge) data(tx.unemp.adj) #Monthly seasonally adjusted Texas unemployment data #Create a quarterly sum my.un.q <- aggregate(tx.unemp.adj,nfreq=4) e.wei <- weidis3(my.un.q,3) sum(e.wei$fin1[1:3]) my.un.q[1]